@@ -5,6 +5,7 @@ from sym.shared.cli.helpers.envvar_option import EnvvarOption
 from sym.shared.cli.helpers.updater import SymUpdater
 
 from sym.cli.decorators import setup_segment, setup_sentry
+from sym.cli.helpers.config import Config
 from sym.cli.helpers.constants import SegmentWriteKey, SentryDSN
 from sym.cli.helpers.global_options import GlobalOptions
 from sym.cli.helpers.sym_group import SymGroup
@@ -29,6 +30,12 @@ from ..version import __version__
 @click.option(
     "--debug", is_flag=True, help="Enable verbose debugging", envvar="SYM_DEBUG"
 )
+@click.option(
+    "--disable-analytics",
+    is_flag=True,
+    help="Disables analytics and telemetry",
+    envvar="SYM_DISABLE_ANALYTICS",
+)
 @click.option("--aws-region", envvar="AWS_REGION", hidden=True)
 @click.option(
     "--log-dir",
@@ -50,6 +57,7 @@ def sym(
     options: GlobalOptions,
     saml_client_name: SAMLClientName,
     debug: bool,
+    disable_analytics: bool,
     resource: str,
     aws_region: str,
     log_dir: Optional[str],
@@ -63,8 +71,12 @@ def sym(
     """
     options.saml_client_type = choose_saml_client(saml_client_name, none_ok=True)
     options.debug = debug
+    options.disable_analytics = disable_analytics
     options.log_dir = log_dir
     options.aws_region = aws_region
     options.session_length = session_length
 
+    if not Config.should_analytics():
+        options.disable_analytics = True
+
     SymUpdater(debug=debug).auto_update()
