@@ -1,10 +1,11 @@
-from .helpers.config import init as config_init
+from sym.shared.cli.helpers.config import init as config_init
 
 config_init("sym")
 
+from sym.shared.cli.helpers.init import sym_init
+
 from .commands import import_all as command_init
 from .commands.sym import sym
-from .helpers.init import sym_init
 
 command_init()
 sym_init()
