@@ -7,6 +7,7 @@ from unittest.mock import ANY, patch
 
 import pytest
 from expects import expect, have_keys
+from sym.shared.cli.tests.conftest import _env_str
 
 from sym.cli.actions.write_creds_action import WriteCredsAction
 from sym.cli.data.request_data import RequestData
@@ -14,7 +15,6 @@ from sym.cli.errors import CliError, InvalidResource, MissingResource
 from sym.cli.helpers.global_options import GlobalOptions
 from sym.cli.saml_clients.aws_okta import AwsOkta
 from sym.cli.sym import sym as click_command
-from sym.cli.tests.conftest import _env_str
 from sym.cli.tests.helpers.sandbox import Sandbox
 
 TEST_PROFILE = "foobar-9000"
