@@ -8,8 +8,7 @@ from unittest.mock import MagicMock, patch
 import pytest
 import responses
 from freezegun import freeze_time
-
-from sym.cli.helpers.updater import SymUpdater
+from sym.shared.cli.helpers.updater import SymUpdater
 
 
 @pytest.fixture
