@@ -1,9 +1,9 @@
 from unittest.mock import patch
 
 import pytest
+from sym.shared.cli.helpers.contexts import push_env
 
 from sym.cli.errors import InvalidResource, UnknownError
-from sym.cli.helpers.contexts import push_env
 from sym.cli.sym import sym as click_command
 from sym.cli.version import __version__
 
@@ -77,7 +77,7 @@ def test_env_vars_override_invalid(click_setup):
             assert "Invalid resource name 'invalid'" in result.output
 
 
-@patch("sym.cli.helpers.updater.SymUpdater.is_local")
+@patch("sym.shared.cli.helpers.updater.SymUpdater.is_local")
 @patch("click.Group.invoke")
 def test_unknown_error(invoke_mock, is_local_mock, click_setup):
     is_local_mock.return_value = False
@@ -89,7 +89,7 @@ def test_unknown_error(invoke_mock, is_local_mock, click_setup):
         assert "foo" in result.output
 
 
-@patch("sym.cli.helpers.updater.SymUpdater.is_local")
+@patch("sym.shared.cli.helpers.updater.SymUpdater.is_local")
 @patch("click.Group.invoke")
 def test_unknown_error_debug(invoke_mock, is_local_mock, click_setup):
     is_local_mock.return_value = False
